@@ -4,7 +4,6 @@
 #' @param cdm cdm_reference via CDMConnector::cdm_from_con()
 #' @param countBy Either "record" for record-level counts or "person" for
 #' person-level counts
-#' @param minCellCount ```r lifecycle::badge("deprecated")```
 #'
 #' @return A tibble with results
 #' @export
@@ -20,12 +19,7 @@
 
 summariseAchillesCodeUse <- function(x,
                             cdm,
-                            countBy = c("record", "person"),
-                            minCellCount = lifecycle::deprecated()) {
-
-  if (lifecycle::is_present(minCellCount)) {
-    lifecycle::deprecate_warn("2.3.0", "summariseAchillesCodeUse()", with = "omopgenerics::suppress()")
-  }
+                            countBy = c("record", "person")) {
 
   errorMessage <- checkmate::makeAssertCollection()
   checkDbType(cdm = cdm, type = "cdm_reference", messageStore = errorMessage)
@@ -42,6 +36,14 @@ summariseAchillesCodeUse <- function(x,
     cli::cli_abort("No achilles tables found in cdm reference")
   }
 
+  if(length(x) == 0){
+    cli::cli_inform(
+      c(
+        "i" = "Empty codelist - no achilles counts to return"
+      ))
+    return(omopgenerics::emptySummarisedResult())
+  }
+
   version <- achillesVersionDate(cdm)
   cli::cli_inform(version)
 
