@@ -21,11 +21,10 @@
 #' @param countBy Either "record" for record-level counts or "person" for
 #' person-level counts
 #' @param byConcept TRUE or FALSE. If TRUE code use will be summarised by
-#'
+#' concept
 #' @param byYear TRUE or FALSE. If TRUE code use will be summarised by year.
 #' @param bySex TRUE or FALSE. If TRUE code use will be summarised by sex.
 #' @param ageGroup If not NULL, a list of ageGroup vectors of length two.
-#' @param minCellCount ```r lifecycle::badge("deprecated")```
 #'
 #' @return A tibble with results overall and, if specified, by strata
 #' @export
@@ -53,12 +52,7 @@ summariseCodeUse <- function(x,
                              byConcept = TRUE,
                              byYear = FALSE,
                              bySex = FALSE,
-                             ageGroup = NULL,
-                             minCellCount = lifecycle::deprecated()){
-
-  if (lifecycle::is_present(minCellCount)) {
-    lifecycle::deprecate_warn("2.3.0", "summariseCodeUse()", with = "omopgenerics::suppress()")
-  }
+                             ageGroup = NULL){
 
   checkmate::assertList(x)
   if(length(names(x)) != length(x)){
@@ -120,7 +114,6 @@ summariseCodeUse <- function(x,
 #' @param byYear TRUE or FALSE. If TRUE code use will be summarised by year.
 #' @param bySex TRUE or FALSE. If TRUE code use will be summarised by sex.
 #' @param ageGroup If not NULL, a list of ageGroup vectors of length two.
-#' @param minCellCount ```r lifecycle::badge("deprecated")```
 #'
 #' @return A tibble with results overall and, if specified, by strata
 #' @export
@@ -157,12 +150,7 @@ summariseCohortCodeUse <- function(x,
                                    byConcept = TRUE,
                                    byYear = FALSE,
                                    bySex = FALSE,
-                                   ageGroup = NULL,
-                                   minCellCount = lifecycle::deprecated()) {
-
-  if (lifecycle::is_present(minCellCount)) {
-    lifecycle::deprecate_warn("2.3.0", "summariseCohortCodeUse()", with = "omopgenerics::suppress()")
-  }
+                                   ageGroup = NULL) {
 
   checkmate::assertList(x)
   if(length(names(x)) != length(x)){
