@@ -320,12 +320,32 @@ test_that("postgres", {
   )
 
   # check orphan code use
-  expect_no_error(summariseOrphanCodes(list("asthma"=317009), cdm))
+  expect_no_error(summariseOrphanCodes(list("asthma"=317009L), cdm))
 
   asthma <- getCandidateCodes(cdm, "asthma", domains = c("condition",
                                                          "observation"))
+
+  expect_identical(subsetOnDomain(list("asthma" = as.integer(asthma$concept_id)),
+                 cdm = cdm,
+                 domain = "condition"),
+  omopgenerics::newCodelist(list("asthma" = sort(as.integer(asthma |>
+    dplyr::filter(domain_id == "Condition") |>
+    dplyr::pull("concept_id"))))))
+  expect_identical(subsetOnDomain(list("asthma" = as.integer(asthma$concept_id)),
+                                  cdm = cdm,
+                                  domain = c("condition", "observation")),
+                   omopgenerics::newCodelist(list("asthma" = sort(as.integer(asthma |>
+                                                                               dplyr::filter(domain_id %in% c("Condition", "Observation")) |>
+                                                                               dplyr::pull("concept_id"))))))
+
+  expect_identical(
+    subsetOnDomain(list("asthma" = as.integer(asthma$concept_id)),
+                 cdm = cdm,
+                 domain = c("procedure")),
+  omopgenerics::emptyCodelist())
+
   asthma_orphan <- summariseOrphanCodes(list(asthma = asthma$concept_id),
-                                        cdm)
+                                        cdm, domain = c("condition"))
 
   # limit orphan codes to a domain
   # we won't have any orphan codes from drug
@@ -432,3 +452,156 @@ test_that("postgres", {
 
   CDMConnector::cdmDisconnect(cdm)
 })
+
+test_that("sql server", {
+
+  testthat::skip_if(Sys.getenv("CDM5_SQL_SERVER_SERVER") == "")
+  testthat::skip_if(Sys.getenv("SQL_SERVER_DRIVER") == "")
+  skip_if_offline()
+
+  db <- DBI::dbConnect(odbc::odbc(),
+                       Driver   = Sys.getenv("SQL_SERVER_DRIVER"),
+                       Server   = Sys.getenv("CDM5_SQL_SERVER_SERVER"),
+                       Database = Sys.getenv("CDM5_SQL_SERVER_CDM_DATABASE"),
+                       UID      = Sys.getenv("CDM5_SQL_SERVER_USER"),
+                       PWD      = Sys.getenv("CDM5_SQL_SERVER_PASSWORD"),
+                       TrustServerCertificate="yes",
+                       Port     = Sys.getenv("CDM5_SQL_SERVER_PORT"))
+  cdm <- CDMConnector::cdm_from_con(db,
+                                    cdm_schema = c("CDMV54", "dbo"),
+                                    achilles_schema = c("CDMV54", "dbo"),
+                                    write_schema = c("ohdsi", "dbo"))
+
+  # check orphan code use
+  expect_no_error(summariseOrphanCodes(list("asthma"=317009L), cdm))
+
+  asthma <- getCandidateCodes(cdm, "asthma", domains = c("condition",
+                                                         "observation"))
+
+  expect_identical(subsetOnDomain(list("asthma" = as.integer(asthma$concept_id)),
+                                  cdm = cdm,
+                                  domain = "condition"),
+                   omopgenerics::newCodelist(list("asthma" = sort(as.integer(asthma |>
+                                                                               dplyr::filter(domain_id == "Condition") |>
+                                                                               dplyr::pull("concept_id"))))))
+  expect_identical(subsetOnDomain(list("asthma" = as.integer(asthma$concept_id)),
+                                  cdm = cdm,
+                                  domain = c("condition", "observation")),
+                   omopgenerics::newCodelist(list("asthma" = sort(as.integer(asthma |>
+                                                                               dplyr::filter(domain_id %in% c("Condition", "Observation")) |>
+                                                                               dplyr::pull("concept_id"))))))
+
+  expect_identical(
+    subsetOnDomain(list("asthma" = as.integer(asthma$concept_id)),
+                   cdm = cdm,
+                   domain = c("procedure")),
+    omopgenerics::emptyCodelist())
+
+  asthma_orphan <- summariseOrphanCodes(list(asthma = asthma$concept_id),
+                                        cdm, domain = c("condition"))
+
+  # limit orphan codes to a domain
+  # we won't have any orphan codes from drug
+  asthma_oc <- summariseOrphanCodes(list("asthma"= c(317009)),
+                                    cdm,
+                                    domain = "drug")
+  expect_true(nrow(asthma_oc) == 0)
+
+
+  codes <- getDrugIngredientCodes(cdm, "metformin")
+  codes[["asthma"]] <- 317009
+
+  expect_no_error(stratifyByDoseUnit(codes, cdm))
+  expect_no_error(stratifyByDoseUnit(codes, cdm, keepOriginal = TRUE))
+  expect_no_error(stratifyByRouteCategory(codes, cdm))
+  expect_no_error(stratifyByRouteCategory(codes, cdm, keepOriginal = TRUE))
+
+
+  drug_codes <- getDrugIngredientCodes(cdm, name = c("metformin",
+                                                     "diclofenac"))
+
+  # we can stratify by each concept contained
+  drug_codes_by_concept <- stratifyByConcept(drug_codes,
+                                             cdm = cdm)
+
+  drug_codes_by_concept_used <- subsetToCodesInUse(drug_codes_by_concept, cdm)
+
+  # if we subset to oral both should still have codes
+  expect_true(length(subsetOnRouteCategory(drug_codes, cdm,
+                                           routeCategory = "oral")) == 2)
+  # only metformin has injectable route
+  expect_true(length(subsetOnRouteCategory(drug_codes, cdm,
+                                           routeCategory = "injectable")) == 1)
+  # we can put multiple route categories
+  # and we should get the same result if we subset up front or later
+  drug_codes2 <- getDrugIngredientCodes(cdm,
+                                        routeCategory = c("injectable",
+                                                          "oral"),
+                                        name = c("metformin","diclofenac"))
+  drug_codes_subset <-  getDrugIngredientCodes(cdm,
+                                               routeCategory = c("injectable",
+                                                                 "oral"),
+                                               name = c("metformin","diclofenac"))
+
+
+  expect_true(length(drug_codes_subset) == 2)
+  expect_identical(drug_codes_subset, drug_codes2)
+
+  # can stratify by route
+  expect_no_error(drug_codes_stratified_by_route <-  getDrugIngredientCodes(cdm,
+                                                                            type = "codelist_with_details",
+                                                                            name = c("metformin","diclofenac")) |>
+                    stratifyByRouteCategory(cdm = cdm))
+  expect_true(inherits(drug_codes_stratified_by_route, "codelist_with_details"))
+
+
+
+  # can subset and stratify by dose unit
+  expect_no_error(getDoseUnit(cdm))
+  drugs <- getDrugIngredientCodes(cdm,
+                                  name = c("metformin","diclofenac"))
+  expect_no_error(subsetOnDoseUnit(drugs, cdm, c("milligram")))
+
+  expect_no_error(drug_codes_stratified_by_unit <-  getDrugIngredientCodes(cdm,
+                                                                           name = c("metformin","diclofenac")) |>
+                    stratifyByDoseUnit(cdm = cdm))
+
+  # we can also stratify by both route and unit
+  expect_no_error(drug_codes_stratified_by_route_and_unit <-  getDrugIngredientCodes(cdm,
+                                                                                     name = c("metformin","diclofenac")) |>
+                    stratifyByRouteCategory(cdm = cdm) |>
+                    stratifyByDoseUnit(cdm = cdm))
+
+  drugs_milligram_transdermal <-  getDrugIngredientCodes(cdm,
+                                                         name = c("metformin","diclofenac"),
+                                                         doseUnit = "milligram",
+                                                         routeCategory = "transdermal")
+
+  drugs_milligram_transdermal_2 <- getDrugIngredientCodes(cdm,
+                                                          name = c("metformin","diclofenac")) |>
+    subsetOnRouteCategory(cdm, "transdermal") |>
+    subsetOnDoseUnit(cdm, "milligram")
+  expect_identical(drugs_milligram_transdermal,
+                   drugs_milligram_transdermal_2)
+
+
+  atc <- getATCCodes(cdm, name = "alimentary tract and metabolism")
+  expect_no_error(atc |>
+                    stratifyByRouteCategory(cdm = cdm) |>
+                    stratifyByDoseUnit(cdm = cdm))
+
+  # make sure no extra domains added to the results
+  codes <- getCandidateCodes(
+    cdm = cdm,
+    keywords = c("at") ,
+    domains = c("Condition", "Observation"),
+    standardConcept = "Standard",
+    searchInSynonyms = FALSE,
+    searchNonStandard = FALSE,
+    includeDescendants = TRUE,
+    includeAncestor = FALSE
+  )
+  expect_true(length(unique(codes$domain_id)) <= 2)
+
+  CDMConnector::cdmDisconnect(cdm)
+})
