@@ -68,7 +68,7 @@ test_that("tests with mock", {
     ))
 
     if (backends[[i]] == "database") {
-      DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
+      CDMConnector::cdm_disconnect(cdm)
     }
   }
 })
